@@ -2,17 +2,17 @@
 from __future__ import annotations
 
 import logging
-from typing import Any
 
 from anthemav.connection import Connection
+from anthemav.protocol import AVR
 import voluptuous as vol
 
 from homeassistant.components.media_player import (
     PLATFORM_SCHEMA,
+    MediaPlayerDeviceClass,
     MediaPlayerEntity,
     MediaPlayerEntityFeature,
 )
-from homeassistant.components.repairs import IssueSeverity, async_create_issue
 from homeassistant.config_entries import SOURCE_IMPORT, ConfigEntry
 from homeassistant.const import (
     CONF_HOST,
@@ -22,11 +22,12 @@ from homeassistant.const import (
     STATE_OFF,
     STATE_ON,
 )
-from homeassistant.core import HomeAssistant
+from homeassistant.core import HomeAssistant, callback
 import homeassistant.helpers.config_validation as cv
 from homeassistant.helpers.dispatcher import async_dispatcher_connect
 from homeassistant.helpers.entity import DeviceInfo
 from homeassistant.helpers.entity_platform import AddEntitiesCallback
+from homeassistant.helpers.issue_registry import IssueSeverity, async_create_issue
 from homeassistant.helpers.typing import ConfigType, DiscoveryInfoType
 
 from .const import (
@@ -85,23 +86,28 @@ async def async_setup_entry(
 ) -> None:
     """Set up entry."""
     name = config_entry.data[CONF_NAME]
-    macaddress = config_entry.data[CONF_MAC]
+    mac_address = config_entry.data[CONF_MAC]
     model = config_entry.data[CONF_MODEL]
 
-    avr = hass.data[DOMAIN][config_entry.entry_id]
+    avr: Connection = hass.data[DOMAIN][config_entry.entry_id]
 
-    device = AnthemAVR(avr, name, macaddress, model)
+    _LOGGER.debug("Connection data dump: %s", avr.dump_conndata)
 
-    _LOGGER.debug("dump_devicedata: %s", device.dump_avrdata)
-    _LOGGER.debug("dump_conndata: %s", avr.dump_conndata)
-
-    async_add_entities([device])
+    async_add_entities(
+        AnthemAVR(
+            avr.protocol, name, mac_address, model, zone_number, config_entry.entry_id
+        )
+        for zone_number in avr.protocol.zones
+    )
 
 
 class AnthemAVR(MediaPlayerEntity):
     """Entity reading values from Anthem AVR protocol."""
 
+    _attr_has_entity_name = True
     _attr_should_poll = False
+    _attr_device_class = MediaPlayerDeviceClass.RECEIVER
+    _attr_icon = "mdi:audio-video"
     _attr_supported_features = (
         MediaPlayerEntityFeature.VOLUME_SET
         | MediaPlayerEntityFeature.VOLUME_MUTE
@@ -110,104 +116,77 @@ class AnthemAVR(MediaPlayerEntity):
         | MediaPlayerEntityFeature.SELECT_SOURCE
     )
 
-    def __init__(self, avr: Connection, name: str, macaddress: str, model: str) -> None:
+    def __init__(
+        self,
+        avr: AVR,
+        name: str,
+        mac_address: str,
+        model: str,
+        zone_number: int,
+        entry_id: str,
+    ) -> None:
         """Initialize entity with transport."""
         super().__init__()
         self.avr = avr
-        self._attr_name = name
-        self._attr_unique_id = macaddress
+        self._entry_id = entry_id
+        self._zone_number = zone_number
+        self._zone = avr.zones[zone_number]
+        if zone_number > 1:
+            self._attr_name = f"zone {zone_number}"
+            self._attr_unique_id = f"{mac_address}_{zone_number}"
+        else:
+            self._attr_unique_id = mac_address
+
         self._attr_device_info = DeviceInfo(
-            identifiers={(DOMAIN, macaddress)},
+            identifiers={(DOMAIN, mac_address)},
             name=name,
             manufacturer=MANUFACTURER,
             model=model,
         )
-
-    def _lookup(self, propname: str, dval: Any | None = None) -> Any | None:
-        return getattr(self.avr.protocol, propname, dval)
+        self.set_states()
 
     async def async_added_to_hass(self) -> None:
         """When entity is added to hass."""
         self.async_on_remove(
             async_dispatcher_connect(
                 self.hass,
-                f"{ANTHEMAV_UDATE_SIGNAL}_{self._attr_name}",
-                self.async_write_ha_state,
+                f"{ANTHEMAV_UDATE_SIGNAL}_{self._entry_id}",
+                self.update_states,
             )
         )
 
-    @property
-    def state(self) -> str | None:
-        """Return state of power on/off."""
-        pwrstate = self._lookup("power")
+    @callback
+    def update_states(self) -> None:
+        """Update states for the current zone."""
+        self.set_states()
+        self.async_write_ha_state()
 
-        if pwrstate is True:
-            return STATE_ON
-        if pwrstate is False:
-            return STATE_OFF
-        return None
-
-    @property
-    def is_volume_muted(self) -> bool | None:
-        """Return boolean reflecting mute state on device."""
-        return self._lookup("mute", False)
-
-    @property
-    def volume_level(self) -> float | None:
-        """Return volume level from 0 to 1."""
-        return self._lookup("volume_as_percentage", 0.0)
-
-    @property
-    def media_title(self) -> str | None:
-        """Return current input name (closest we have to media title)."""
-        return self._lookup("input_name", "No Source")
-
-    @property
-    def app_name(self) -> str | None:
-        """Return details about current video and audio stream."""
-        return (
-            f"{self._lookup('video_input_resolution_text', '')} "
-            f"{self._lookup('audio_input_name', '')}"
-        )
-
-    @property
-    def source(self) -> str | None:
-        """Return currently selected input."""
-        return self._lookup("input_name", "Unknown")
-
-    @property
-    def source_list(self) -> list[str] | None:
-        """Return all active, configured inputs."""
-        return self._lookup("input_list", ["Unknown"])
+    def set_states(self) -> None:
+        """Set all the states from the device to the entity."""
+        self._attr_state = STATE_ON if self._zone.power is True else STATE_OFF
+        self._attr_is_volume_muted = self._zone.mute
+        self._attr_volume_level = self._zone.volume_as_percentage
+        self._attr_media_title = self._zone.input_name
+        self._attr_app_name = self._zone.input_format
+        self._attr_source = self._zone.input_name
+        self._attr_source_list = self.avr.input_list
 
     async def async_select_source(self, source: str) -> None:
         """Change AVR to the designated source (by name)."""
-        self._update_avr("input_name", source)
+        self._zone.input_name = source
 
     async def async_turn_off(self) -> None:
         """Turn AVR power off."""
-        self._update_avr("power", False)
+        self._zone.power = False
 
     async def async_turn_on(self) -> None:
         """Turn AVR power on."""
-        self._update_avr("power", True)
+        self._zone.power = True
 
     async def async_set_volume_level(self, volume: float) -> None:
         """Set AVR volume (0 to 1)."""
-        self._update_avr("volume_as_percentage", volume)
+        self._zone.volume_as_percentage = volume
 
     async def async_mute_volume(self, mute: bool) -> None:
         """Engage AVR mute."""
-        self._update_avr("mute", mute)
-
-    def _update_avr(self, propname: str, value: Any | None) -> None:
-        """Update a property in the AVR."""
-        _LOGGER.debug("Sending command to AVR: set %s to %s", propname, str(value))
-        setattr(self.avr.protocol, propname, value)
-
-    @property
-    def dump_avrdata(self):
-        """Return state of avr object for debugging forensics."""
-        attrs = vars(self)
-        items_string = ", ".join(f"{item}: {item}" for item in attrs.items())
-        return f"dump_avrdata: {items_string}"
+        self._zone.mute = mute
