@@ -2,6 +2,7 @@
 from __future__ import annotations
 
 import logging
+from typing import Any
 
 from homeassistant.components import (
     alarm_control_panel,
@@ -68,6 +69,10 @@ from homeassistant.const import (
 from homeassistant.core import DOMAIN as HA_DOMAIN
 from homeassistant.helpers.network import get_url
 from homeassistant.util import color as color_util, dt, temperature as temp_util
+from homeassistant.util.percentage import (
+    ordered_list_item_to_percentage,
+    percentage_to_ordered_list_item,
+)
 
 from .const import (
     CHALLENGE_ACK_NEEDED,
@@ -82,6 +87,7 @@ from .const import (
     ERR_NOT_SUPPORTED,
     ERR_UNSUPPORTED_INPUT,
     ERR_VALUE_OUT_OF_RANGE,
+    FAN_SPEEDS,
 )
 from .error import ChallengeNeeded, SmartHomeError
 
@@ -157,6 +163,8 @@ COMMAND_CHARGE = f"{PREFIX_COMMANDS}Charge"
 
 TRAITS = []
 
+FAN_SPEED_MAX_SPEED_COUNT = 5
+
 
 def register_trait(trait):
     """Decorate a function to register a trait."""
@@ -864,13 +872,13 @@ class TemperatureSettingTrait(_Trait):
     # We do not support "on" as we are unable to know how to restore
     # the last mode.
     hvac_to_google = {
-        climate.HVAC_MODE_HEAT: "heat",
-        climate.HVAC_MODE_COOL: "cool",
-        climate.HVAC_MODE_OFF: "off",
-        climate.HVAC_MODE_AUTO: "auto",
-        climate.HVAC_MODE_HEAT_COOL: "heatcool",
-        climate.HVAC_MODE_FAN_ONLY: "fan-only",
-        climate.HVAC_MODE_DRY: "dry",
+        climate.HVACMode.HEAT: "heat",
+        climate.HVACMode.COOL: "cool",
+        climate.HVACMode.OFF: "off",
+        climate.HVACMode.AUTO: "auto",
+        climate.HVACMode.HEAT_COOL: "heatcool",
+        climate.HVACMode.FAN_ONLY: "fan-only",
+        climate.HVACMode.DRY: "dry",
     }
     google_to_hvac = {value: key for key, value in hvac_to_google.items()}
 
@@ -949,7 +957,7 @@ class TemperatureSettingTrait(_Trait):
         if current_humidity is not None:
             response["thermostatHumidityAmbient"] = current_humidity
 
-        if operation in (climate.HVAC_MODE_AUTO, climate.HVAC_MODE_HEAT_COOL):
+        if operation in (climate.HVACMode.AUTO, climate.HVACMode.HEAT_COOL):
             if supported & climate.SUPPORT_TARGET_TEMPERATURE_RANGE:
                 response["thermostatTemperatureSetpointHigh"] = round(
                     temp_util.convert(
@@ -1359,6 +1367,20 @@ class ArmDisArmTrait(_Trait):
         )
 
 
+def _get_fan_speed(speed_name: str) -> dict[str, Any]:
+    """Return a fan speed synonyms for a speed name."""
+    speed_synonyms = FAN_SPEEDS.get(speed_name, [f"{speed_name}"])
+    return {
+        "speed_name": speed_name,
+        "speed_values": [
+            {
+                "speed_synonym": speed_synonyms,
+                "lang": "en",
+            }
+        ],
+    }
+
+
 @register_trait
 class FanSpeedTrait(_Trait):
     """Trait to control speed of Fan.
@@ -1369,6 +1391,20 @@ class FanSpeedTrait(_Trait):
     name = TRAIT_FANSPEED
     commands = [COMMAND_FANSPEED, COMMAND_REVERSE]
 
+    def __init__(self, hass, state, config):
+        """Initialize a trait for a state."""
+        super().__init__(hass, state, config)
+        if state.domain == fan.DOMAIN:
+            speed_count = min(
+                FAN_SPEED_MAX_SPEED_COUNT,
+                round(
+                    100 / (self.state.attributes.get(fan.ATTR_PERCENTAGE_STEP) or 1.0)
+                ),
+            )
+            self._ordered_speed = [
+                f"{speed}/{speed_count}" for speed in range(1, speed_count + 1)
+            ]
+
     @staticmethod
     def supported(domain, features, device_class, _):
         """Test if state is supported."""
@@ -1397,6 +1433,18 @@ class FanSpeedTrait(_Trait):
                 }
             )
 
+            if self._ordered_speed:
+                result.update(
+                    {
+                        "availableFanSpeeds": {
+                            "speeds": [
+                                _get_fan_speed(speed) for speed in self._ordered_speed
+                            ],
+                            "ordered": True,
+                        },
+                    }
+                )
+
         elif domain == climate.DOMAIN:
             modes = self.state.attributes.get(climate.ATTR_FAN_MODES) or []
             for mode in modes:
@@ -1428,6 +1476,9 @@ class FanSpeedTrait(_Trait):
         if domain == fan.DOMAIN:
             percent = attrs.get(fan.ATTR_PERCENTAGE) or 0
             response["currentFanSpeedPercent"] = percent
+            response["currentFanSpeedSetting"] = percentage_to_ordered_list_item(
+                self._ordered_speed, percent
+            )
 
         return response
 
@@ -1447,12 +1498,19 @@ class FanSpeedTrait(_Trait):
             )
 
         if domain == fan.DOMAIN:
+            if fan_speed := params.get("fanSpeed"):
+                fan_speed_percent = ordered_list_item_to_percentage(
+                    self._ordered_speed, fan_speed
+                )
+            else:
+                fan_speed_percent = params.get("fanSpeedPercent")
+
             await self.hass.services.async_call(
                 fan.DOMAIN,
                 fan.SERVICE_SET_PERCENTAGE,
                 {
                     ATTR_ENTITY_ID: self.state.entity_id,
-                    fan.ATTR_PERCENTAGE: params["fanSpeedPercent"],
+                    fan.ATTR_PERCENTAGE: fan_speed_percent,
                 },
                 blocking=not self.config.should_report_state,
                 context=data.context,
