@@ -10,12 +10,10 @@ from homeassistant.components.light import (
     ATTR_FLASH,
     ATTR_HS_COLOR,
     ATTR_TRANSITION,
-    ATTR_WHITE_VALUE,
     ENTITY_ID_FORMAT,
     SUPPORT_BRIGHTNESS,
     SUPPORT_COLOR,
     SUPPORT_COLOR_TEMP,
-    SUPPORT_WHITE_VALUE,
     LightEntity,
     LightEntityFeature,
 )
@@ -84,7 +82,6 @@ _PLATFORM_SCHEMA_BASE = (
             vol.Optional(CONF_OPTIMISTIC, default=DEFAULT_OPTIMISTIC): cv.boolean,
             vol.Optional(CONF_RED_TEMPLATE): cv.template,
             vol.Optional(CONF_STATE_TEMPLATE): cv.template,
-            vol.Optional(CONF_WHITE_VALUE_TEMPLATE): cv.template,
         }
     )
     .extend(MQTT_ENTITY_COMMON_SCHEMA.schema)
@@ -93,18 +90,20 @@ _PLATFORM_SCHEMA_BASE = (
 
 # Configuring MQTT Lights under the light platform key is deprecated in HA Core 2022.6
 PLATFORM_SCHEMA_TEMPLATE = vol.All(
-    # CONF_WHITE_VALUE_TEMPLATE is deprecated, support will be removed in release 2022.9
-    cv.deprecated(CONF_WHITE_VALUE_TEMPLATE),
     cv.PLATFORM_SCHEMA.extend(_PLATFORM_SCHEMA_BASE.schema),
 )
 
 DISCOVERY_SCHEMA_TEMPLATE = vol.All(
-    # CONF_WHITE_VALUE_TEMPLATE is deprecated, support will be removed in release 2022.9
-    cv.deprecated(CONF_WHITE_VALUE_TEMPLATE),
+    # CONF_WHITE_VALUE_TEMPLATE is no longer supported, support was removed in 2022.9
+    cv.removed(CONF_WHITE_VALUE_TEMPLATE),
     _PLATFORM_SCHEMA_BASE.extend({}, extra=vol.REMOVE_EXTRA),
 )
 
-PLATFORM_SCHEMA_MODERN_TEMPLATE = _PLATFORM_SCHEMA_BASE
+PLATFORM_SCHEMA_MODERN_TEMPLATE = vol.All(
+    # CONF_WHITE_VALUE_TEMPLATE is no longer supported, support was removed in 2022.9
+    cv.removed(CONF_WHITE_VALUE_TEMPLATE),
+    _PLATFORM_SCHEMA_BASE,
+)
 
 
 async def async_setup_entity_template(
@@ -131,7 +130,6 @@ class MqttLightTemplate(MqttEntity, LightEntity, RestoreEntity):
         # features
         self._brightness = None
         self._color_temp = None
-        self._white_value = None
         self._hs = None
         self._effect = None
 
@@ -159,7 +157,6 @@ class MqttLightTemplate(MqttEntity, LightEntity, RestoreEntity):
                 CONF_GREEN_TEMPLATE,
                 CONF_RED_TEMPLATE,
                 CONF_STATE_TEMPLATE,
-                CONF_WHITE_VALUE_TEMPLATE,
             )
         }
         optimistic = config[CONF_OPTIMISTIC]
@@ -236,16 +233,6 @@ class MqttLightTemplate(MqttEntity, LightEntity, RestoreEntity):
                 except ValueError:
                     _LOGGER.warning("Invalid color value received")
 
-            if self._templates[CONF_WHITE_VALUE_TEMPLATE] is not None:
-                try:
-                    self._white_value = int(
-                        self._templates[
-                            CONF_WHITE_VALUE_TEMPLATE
-                        ].async_render_with_possible_json_value(msg.payload)
-                    )
-                except ValueError:
-                    _LOGGER.warning("Invalid white value received")
-
             if self._templates[CONF_EFFECT_TEMPLATE] is not None:
                 effect = self._templates[
                     CONF_EFFECT_TEMPLATE
@@ -287,8 +274,6 @@ class MqttLightTemplate(MqttEntity, LightEntity, RestoreEntity):
                 self._color_temp = last_state.attributes.get(ATTR_COLOR_TEMP)
             if last_state.attributes.get(ATTR_EFFECT):
                 self._effect = last_state.attributes.get(ATTR_EFFECT)
-            if last_state.attributes.get(ATTR_WHITE_VALUE):
-                self._white_value = last_state.attributes.get(ATTR_WHITE_VALUE)
 
     @property
     def brightness(self):
@@ -315,11 +300,6 @@ class MqttLightTemplate(MqttEntity, LightEntity, RestoreEntity):
         """Return the hs color value [int, int]."""
         return self._hs
 
-    @property
-    def white_value(self):
-        """Return the white property."""
-        return self._white_value
-
     @property
     def is_on(self):
         """Return True if entity is on."""
@@ -385,12 +365,6 @@ class MqttLightTemplate(MqttEntity, LightEntity, RestoreEntity):
             if self._optimistic:
                 self._hs = kwargs[ATTR_HS_COLOR]
 
-        if ATTR_WHITE_VALUE in kwargs:
-            values["white_value"] = int(kwargs[ATTR_WHITE_VALUE])
-
-            if self._optimistic:
-                self._white_value = kwargs[ATTR_WHITE_VALUE]
-
         if ATTR_EFFECT in kwargs:
             values["effect"] = kwargs.get(ATTR_EFFECT)
 
@@ -457,7 +431,5 @@ class MqttLightTemplate(MqttEntity, LightEntity, RestoreEntity):
             features = features | LightEntityFeature.EFFECT
         if self._templates[CONF_COLOR_TEMP_TEMPLATE] is not None:
             features = features | SUPPORT_COLOR_TEMP
-        if self._templates[CONF_WHITE_VALUE_TEMPLATE] is not None:
-            features = features | SUPPORT_WHITE_VALUE
 
         return features
